import logging
import torch.distributed as dist

INFO = logging.INFO
WARNING = logging.WARNING
ERROR = logging.ERROR
FATAL = logging.FATAL
CRITICAL = logging.CRITICAL

class Indicator(object):
    def __init__(self, is_dist=False, output_rank=0):
        self.is_dist = is_dist
        self.output_rank = output_rank
    
indicator = Indicator()

def set_dist(is_dist=False):
    indicator.is_dist = is_dist
    if is_dist:
        logging.info("Set logger to DISTRIBUTED mode!")

def info(msg, *args, **kwargs):
    if indicator.is_dist:
        rank = dist.get_rank()
        if rank == indicator.output_rank:
            logging.info(msg, *args, **kwargs)
    else:
        logging.info(msg, *args, **kwargs)

def warning(msg, *args, **kwargs):
    if indicator.is_dist:
        rank = dist.get_rank()
        if rank == indicator.output_rank:
            logging.warning(msg, *args, **kwargs)
    else:
        logging.warning(msg, *args, **kwargs)

getLogger = logging.getLogger

if __name__ == "__main__":
    warning("test")


from tqdm import tqdm as tqdm_ori
import torch.distributed as dist

class TqdmWithoutPrint:
    def __init__(self, iterable):
        self.iterable = iterable
    
    def __iter__(self):
        for item in iter(self.iterable):
            yield item
    
    def set_description(self, string, *args, **kwargs):
        # do nothing
        pass

    def close(self):
        # do nothing
        pass

def tqdm(iterable):
    if dist.is_initialized():
        if dist.get_rank() == 0:
            return tqdm_ori(iterable)
        else:
            return TqdmWithoutPrint(iterable)
    else:
        return tqdm_ori(iterable)
    
